==> cutetube_1.7.1.tar.gz: cutetube-1.7.1/cutetubeapp/src/base/socialvideolistmodel.h <==
#ifndef SOCIALVIDEOLISTMODEL_H
#define SOCIALVIDEOLISTMODEL_H

#include "videoitem.h"
#include <QAbstractListModel>
#include <QSharedPointer>

class Session;
class ThumbnailCache;

class SocialVideoListModel : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(Session* session
               READ session
               WRITE setSession)
    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)
    Q_PROPERTY(bool itemsSelected
               READ itemsSelected
               NOTIFY itemsSelectedChanged)

public:
    enum Roles {
        IdRole = Qt::UserRole + 1,
        VideoIdRole,
        FavouriteIdRole,
        PlaylistVideoIdRole,
        TitleRole,
        ArtistRole,
        DateRole,
        DurationRole,
        ViewCountRole,
        RatingCountRole,
        RatingRole,
        ThumbnailRole,
        ThumbnailUrlRole,
        ArchiveRole,
        ServiceRole,
        FavouriteRole,
        SelectedRole,
        ThumbnailPressedRole
    };

public:
    explicit SocialVideoListModel(Session *session = 0, QObject *parent = 0);
    ~SocialVideoListModel();
    inline Session* session() const { return m_session; }
    void setSession(Session *session);
    inline ThumbnailCache* thumbnailCache() const { return m_cache; }
    void setThumbnailCache(ThumbnailCache *cache);
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    QSharedPointer<VideoItem> get(int row) const;
    Q_INVOKABLE VideoItem* getFromQML(int row) const;
    Q_INVOKABLE QList<int> selectedRows() const { return m_selectedRows; }
    QList< QSharedPointer<VideoItem> > selectedItems() const;
    Q_INVOKABLE QList<VideoItem*> selectedItemsFromQML() const;
    inline bool itemsSelected() const { return !this->selectedRows().isEmpty(); }

public slots:
    void selectAll();
    void selectNone();
    void toggleSelected(int row);
    void downloadSelectedVideos(bool saveAsAudio = false);
    void queueSelectedVideos();

private slots:
    void onVideoAdded(int row);
    void onThumbnailReady();

signals:
    void countChanged(int count);
    void itemsSelectedChanged(bool selected);

private:
    Session *m_session;
    ThumbnailCache *m_cache;
    QList<int> m_selectedRows;
    int m_thumbnailPressedRow;
};

#endif // SOCIALVIDEOLISTMODEL_H

==> cutetube_1.7.6.tar.gz: cutetube-1.7.6/cutetubeapp/src/base/socialvideolistmodel.h <==
#ifndef SOCIALVIDEOLISTMODEL_H
#define SOCIALVIDEOLISTMODEL_H

#include "videoitem.h"
#include <QAbstractListModel>
#include <QSharedPointer>

#ifndef QML_USER_INTERFACE
class ThumbnailCache;
#endif

class SocialVideoListModel : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)
    Q_PROPERTY(bool itemsSelected
               READ itemsSelected
               NOTIFY itemsSelectedChanged)

public:
    enum Roles {
        IdRole = Qt::UserRole + 1,
        VideoIdRole,
        FavouriteIdRole,
        PlaylistVideoIdRole,
        TitleRole,
        ArtistRole,
        DateRole,
        DurationRole,
        ViewCountRole,
        RatingCountRole,
        RatingRole,
#ifndef QML_USER_INTERFACE
        ThumbnailRole,
        ThumbnailPressedRole,
#endif
        ThumbnailUrlRole,
        ArchiveRole,
        ServiceRole,
        FavouriteRole,
        SelectedRole
    };

public:
    explicit SocialVideoListModel(QObject *parent = 0);
    ~SocialVideoListModel();
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    QSharedPointer<VideoItem> get(int row) const;
#ifdef QML_USER_INTERFACE
    Q_INVOKABLE VideoItem* getFromQML(int row) const;
#endif
    Q_INVOKABLE QList<int> selectedRows() const { return m_selectedRows; }
    QList< QSharedPointer<VideoItem> > selectedItems() const;
#ifdef QML_USER_INTERFACE
    Q_INVOKABLE QList<VideoItem*> selectedItemsFromQML() const;
#endif
    inline bool itemsSelected() const { return !this->selectedRows().isEmpty(); }

public slots:
    void selectAll();
    void selectNone();
    void toggleSelected(int row);
    void downloadSelectedVideos(bool saveAsAudio = false);
    void queueSelectedVideos();

private slots:
    void onVideoAdded(int row);
#ifndef QML_USER_INTERFACE
    void onThumbnailReady();
#endif

signals:
    void countChanged(int count);
    void itemsSelectedChanged(bool selected);

private:
#ifndef QML_USER_INTERFACE
    ThumbnailCache *m_cache;
    int m_thumbnailPressedRow;
#endif
    QList<int> m_selectedRows;
};

#endif // SOCIALVIDEOLISTMODEL_H
